@@ -210,7 +210,7 @@ void DVideoWidget::setSourceVideoPixelRatio(const qreal ratio)
     d->ratio = ratio;
 }
 
-const qreal DVideoWidget::sourceVideoPixelRatio() const
+qreal DVideoWidget::sourceVideoPixelRatio() const
 {
     D_DC(DVideoWidget);
 
